<?php
namespace Concrete\Package\C5rYaUpdateConstructor;

defined('C5_EXECUTE') or die('Access Denied.');

use Concrete\Core\Package\Package;
use Concrete\Core\Page\Page;
use Concrete\Core\Page\Single as SinglePage;
use Concrete\Core\Support\Facade\Application;
use Concrete\Core\Support\Facade\Events;
use Concrete\Core\View\View;

class Controller extends Package
{
    protected $pkgHandle = 'c5r_ya_update_constructor';
    protected $appVersionRequired = '5.7.1';
    protected $pkgVersion = '1.0.0';

    public function getPackageDescription()
    {
        return t('Adds a notification about outdated or not compatible browser');
    }

    public function getPackageName()
    {
        return t('C5R browser update constructor');
    }

    public function install()
    {
        $pkg = parent::install();
        $this->installSinglePages($pkg);

        $pkg->getFileConfig()->save('c5r.ya_update_constructor.ncEnabled', false);
        $pkg->getFileConfig()->save('c5r.ya_update_constructor.ncType', '0');
        $pkg->getFileConfig()->save('c5r.ya_update_constructor.ncLanguage', 'ru');
        $pkg->getFileConfig()->save('c5r.ya_update_constructor.ncColor', 'yellow');

        //outdated browser
        $pkg->getFileConfig()->save('c5r.ya_update_constructor.ncYabrowser', true);
        $pkg->getFileConfig()->save('c5r.ya_update_constructor.ncYabrowserVersion', '16.12');
        $pkg->getFileConfig()->save('c5r.ya_update_constructor.ncChromeBrowser', true);
        $pkg->getFileConfig()->save('c5r.ya_update_constructor.ncChromeVersion', '62');
        $pkg->getFileConfig()->save('c5r.ya_update_constructor.ncIeBrowser', true);
        $pkg->getFileConfig()->save('c5r.ya_update_constructor.ncIeVersion', '10');
        $pkg->getFileConfig()->save('c5r.ya_update_constructor.ncOperaBrowser', true);
        $pkg->getFileConfig()->save('c5r.ya_update_constructor.ncOperaVersion', '49');
        $pkg->getFileConfig()->save('c5r.ya_update_constructor.ncSafariBrowser', true);
        $pkg->getFileConfig()->save('c5r.ya_update_constructor.ncSafariVersion', '9.1');
        $pkg->getFileConfig()->save('c5r.ya_update_constructor.ncFxBrowser', true);
        $pkg->getFileConfig()->save('c5r.ya_update_constructor.ncFxVersion', '57');
        $pkg->getFileConfig()->save('c5r.ya_update_constructor.ncIronBrowser', true);
        $pkg->getFileConfig()->save('c5r.ya_update_constructor.ncIronVersion', '35');
        $pkg->getFileConfig()->save('c5r.ya_update_constructor.ncFlockBrowser', true);
        $pkg->getFileConfig()->save('c5r.ya_update_constructor.ncFlockVersion', 'Infinity');
        $pkg->getFileConfig()->save('c5r.ya_update_constructor.ncPalemoonBrowser', true);
        $pkg->getFileConfig()->save('c5r.ya_update_constructor.ncPalemoonVersion', '25');
        $pkg->getFileConfig()->save('c5r.ya_update_constructor.ncCaminoBrowser', true);
        $pkg->getFileConfig()->save('c5r.ya_update_constructor.ncCaminoVersion', 'Infinity');
        $pkg->getFileConfig()->save('c5r.ya_update_constructor.ncMaxthonBrowser', true);
        $pkg->getFileConfig()->save('c5r.ya_update_constructor.ncMaxthonVersion', '4.5');
        $pkg->getFileConfig()->save('c5r.ya_update_constructor.ncSeamonkeyBrowser', true);
        $pkg->getFileConfig()->save('c5r.ya_update_constructor.ncSeamonkeyVersion', '2.3');

        // compatible browser
        $pkg->getFileConfig()->save('c5r.ya_update_constructor.ncCompatibleBrowser', 'yabrowser');
    }


    private function installSinglePages($pkg)
    {
        $this->installSinglePage('/dashboard/ya_update_constructor', t('Browser update constructor settings'), t('A page provides a constructor for building notifications about outdated or not compatible browser.'), $pkg);
    }

    private function installSinglePage($path, $cName, $cDescription, $pkg)
    {
        $page = Page::getByPath($path);

        if (!is_object($page) || $page->isError()) {
            $page = SinglePage::add($path, $pkg);
            $page->update(array(
                'cName' => $cName,
                'cDescription' => $cDescription,
            ));
        }
    }

    public function on_start()
    {

        Events::addListener(
            'on_page_view',
            function ($e) {
                $app = Application::getFacadeApplication();
                $html = $app->make('helper/html');
                $page = $e->getPageObject();
                $systemPage = $page->isAdminArea();
                $pkg = Package::getByHandle('c5r_ya_update_constructor');
                $enabled = $pkg->getFileConfig()->get('c5r.ya_update_constructor.ncEnabled');

                if(!$systemPage && $enabled > 0) {

                    $ncType = $pkg->getFileConfig()->get('c5r.ya_update_constructor.ncType');
                    $ncLanguage = $pkg->getFileConfig()->get('c5r.ya_update_constructor.ncLanguage');
                    $ncColor = $pkg->getFileConfig()->get('c5r.ya_update_constructor.ncColor');

                    // compatible browser
                    $ncCompatibleBrowser = $pkg->getFileConfig()->get('c5r.ya_update_constructor.ncCompatibleBrowser');

                    // outdated browser
                    $ncYabrowser = $pkg->getFileConfig()->get('c5r.ya_update_constructor.ncYabrowser');
                    $ncYabrowserVersion = $pkg->getFileConfig()->get('c5r.ya_update_constructor.ncYabrowserVersion');
                    $ncChromeBrowser = $pkg->getFileConfig()->get('c5r.ya_update_constructor.ncChromeBrowser');
                    $ncChromeVersion = $pkg->getFileConfig()->get('c5r.ya_update_constructor.ncChromeVersion');
                    $ncIeBrowser = $pkg->getFileConfig()->get('c5r.ya_update_constructor.ncIeBrowser');
                    $ncIeVersion = $pkg->getFileConfig()->get('c5r.ya_update_constructor.ncIeVersion');
                    $ncOperaBrowser = $pkg->getFileConfig()->get('c5r.ya_update_constructor.ncOperaBrowser');
                    $ncOperaVersion = $pkg->getFileConfig()->get('c5r.ya_update_constructor.ncOperaVersion');
                    $ncSafariBrowser = $pkg->getFileConfig()->get('c5r.ya_update_constructor.ncSafariBrowser');
                    $ncSafariVersion = $pkg->getFileConfig()->get('c5r.ya_update_constructor.ncSafariVersion');
                    $ncFxBrowser = $pkg->getFileConfig()->get('c5r.ya_update_constructor.ncFxBrowser');
                    $ncFxVersion = $pkg->getFileConfig()->get('c5r.ya_update_constructor.ncFxVersion');
                    $ncIronBrowser = $pkg->getFileConfig()->get('c5r.ya_update_constructor.ncIronBrowser');
                    $ncIronVersion = $pkg->getFileConfig()->get('c5r.ya_update_constructor.ncIronVersion');
                    $ncFlockBrowser = $pkg->getFileConfig()->get('c5r.ya_update_constructor.ncFlockBrowser');
                    $ncFlockVersion = $pkg->getFileConfig()->get('c5r.ya_update_constructor.ncFlockVersion');
                    $ncPalemoonBrowser = $pkg->getFileConfig()->get('c5r.ya_update_constructor.ncPalemoonBrowser');
                    $ncPalemoonVersion = $pkg->getFileConfig()->get('c5r.ya_update_constructor.ncPalemoonVersion');
                    $ncCaminoBrowser = $pkg->getFileConfig()->get('c5r.ya_update_constructor.ncCaminoBrowser');
                    $ncCaminoVersion = $pkg->getFileConfig()->get('c5r.ya_update_constructor.ncCaminoVersion');
                    $ncMaxthonBrowser = $pkg->getFileConfig()->get('c5r.ya_update_constructor.ncMaxthonBrowser');
                    $ncMaxthonVersion = $pkg->getFileConfig()->get('c5r.ya_update_constructor.ncMaxthonVersion');
                    $ncSeamonkeyBrowser = $pkg->getFileConfig()->get('c5r.ya_update_constructor.ncSeamonkeyBrowser');
                    $ncSeamonkeyVersion = $pkg->getFileConfig()->get('c5r.ya_update_constructor.ncSeamonkeyVersion');

                    $chromiumParam = ($ncChromeBrowser) ? 'chromium: ' . "\"$ncChromeVersion" . "\",": '';
                    $ieParam = ($ncIeBrowser) ? 'ie: ' . "\"$ncIeVersion" . "\",": '';
                    $yaBrowserParam = ($ncYabrowser) ? 'yabrowser: ' . "\"$ncYabrowserVersion" . "\",": '';
                    $operaParam = ($ncOperaBrowser) ? 'opera: ' . "\"$ncOperaVersion" . "\",": '';
                    $safariParam = ($ncSafariBrowser) ? 'safari: ' . "\"$ncSafariVersion" . "\",": '';
                    $fxParam = ($ncFxBrowser) ? 'fx: ' . "\"$ncFxVersion" . "\",": '';
                    $ironParam = ($ncIronBrowser) ? 'iron: ' . "\"$ncIronVersion" . "\",": '';
                    $flockParam = ($ncFlockBrowser) ? 'flock: ' . "\"$ncFlockVersion" . "\",": '';
                    $palemoonParam = ($ncPalemoonBrowser) ? 'palemoon: ' . "\"$ncPalemoonVersion" . "\",": '';
                    $caminoParam = ($ncCaminoBrowser) ? 'camino: ' . "\"$ncCaminoVersion" . "\",": '';
                    $maxthonParam = ($ncMaxthonBrowser) ? 'maxthon: ' . "\"$ncMaxthonVersion" . "\",": '';
                    $seamonkeyParam = ($ncSeamonkeyBrowser) ? 'seamonkey: ' . "\"$ncSeamonkeyVersion" . "\",": '';

                    // output to dom
                    $v = View::getInstance();
                    $v->addFooterItem('<script src="https://yastatic.net/browser-updater/v1/script.js" charset="utf-8"></script>');
                    $v->addHeaderItem($html->css('update_constructor.css', $this->pkgHandle));


if ($ncType == '1') {
    $v->addFooterItem(<<<EOT
<script>
    window.onload = function() {
        var browserUpdater = new ya.browserUpdater.init(
         {
            lang: "{$ncLanguage}",
            exclusive: true,
            browsers: "{$ncCompatibleBrowser}"
         });
        };
</script>
EOT
    );

} else {
    $v->addFooterItem(<<<EOT
<script>
window.onload = function() {
    var browserUpdater = new ya.browserUpdater.init(
     {
        theme: "{$ncColor}",
        lang: "{$ncLanguage}",
        exclusive: false,
        browsers: {
          {$yaBrowserParam}
          {$chromiumParam}
          {$ieParam}
          {$operaParam}
          {$safariParam}
          {$fxParam}
          {$ironParam}
          {$flockParam}
          {$palemoonParam}
          {$caminoParam}
          {$maxthonParam}
          {$seamonkeyParam}
        },
        remember: true,
        rememberFor: 30
     });
    }
</script>
EOT
    );
}
                }
            }
        );

    }
}